#include <stdio.h>
#include <string.h>

int	main() {

	char in[4096];
	FILE *f1;

	while (1) {

		if (fgets(in, 4096, stdin) == NULL) break;
		in[strlen(in)-1] = 0;
		f1 = fopen(in,"r");
		if (f1 == NULL) printf("missing: %s\n", in);
		else fclose (f1);
		}
	}
