/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Glade / Gtk Programming
#+
#+     Copyright (C) 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     http://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Oct 21, 2022

#ifndef COMMON_OBJECTS_H
#define COMMON_OBJECTS_H

#define QUOTE "\""

#define mkstr(s) #s

#define TILE_WIDGETS(NBR) \
	p ##NBR = GTK_WIDGET(gtk_builder_get_object(builder, mkstr(p ## NBR) ));  \
	lbl ##NBR = GTK_WIDGET(gtk_builder_get_object(builder, mkstr(lbl ## NBR) ));  \
	p ## NBR ##TimeEnd = GTK_WIDGET(gtk_builder_get_object(builder, mkstr(p ## NBR ##TimeEnd) ));  \
	p ## NBR ##Time = GTK_WIDGET(gtk_builder_get_object(builder, mkstr(p ## NBR ##Time) ));  \
	p ## NBR ##TimeLength = GTK_WIDGET(gtk_builder_get_object(builder, mkstr(p ## NBR ##TimeLength) ));

pg_edit			= GTK_WIDGET(gtk_builder_get_object(builder, "pg_edit"));
au_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "au_fixed"));
pg8_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "pg8_fixed"));
ct_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "ct_fixed"));
TopBG			 = GTK_WIDGET(gtk_builder_get_object(builder, "TopBG"));
ed_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "ed_fixed"));
pg_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "pg_fixed"));
video_bg		= GTK_WIDGET(gtk_builder_get_object(builder, "video_bg"));
video_bg1		= GTK_WIDGET(gtk_builder_get_object(builder, "video_bg1"));
art_metadata		= GTK_WIDGET(gtk_builder_get_object(builder, "art_metadata"));
sprinkleDamp		= GTK_WIDGET(gtk_builder_get_object(builder, "sprinkleDamp"));
noBackPic		= GTK_WIDGET(gtk_builder_get_object(builder, "noBackPic"));
solid_digital_arcs	= GTK_WIDGET(gtk_builder_get_object(builder, "solid_digital_arcs"));
d1mask			= GTK_WIDGET(gtk_builder_get_object(builder, "d1mask"));
no_graphs		= GTK_WIDGET(gtk_builder_get_object(builder, "no_graphs"));
web2_clear		= GTK_WIDGET(gtk_builder_get_object(builder, "web2_clear"));
// large462		= GTK_WIDGET(gtk_builder_get_object(builder, "large462"));
web_panel		= GTK_WIDGET(gtk_builder_get_object(builder, "web_panel"));
vlcX			= GTK_WIDGET(gtk_builder_get_object(builder, "vlcX"));
agc_gain		= GTK_WIDGET(gtk_builder_get_object(builder, "agc_gain"));
mpv_player		= GTK_WIDGET(gtk_builder_get_object(builder, "mpv_player"));
web_settings		= WEBKIT_SETTINGS(gtk_builder_get_object(builder, "web_settings"));
web_playlist		= GTK_WIDGET(gtk_builder_get_object(builder, "web_playlist"));
webkit			= GTK_WIDGET(gtk_builder_get_object(builder, "webkit"));
video_panel		= GTK_WIDGET(gtk_builder_get_object(builder, "video_panel"));
radio_vu		= GTK_WIDGET(gtk_builder_get_object(builder, "radio_vu"));
radio_bars		= GTK_WIDGET(gtk_builder_get_object(builder, "radio_bars"));
radio_digital		= GTK_WIDGET(gtk_builder_get_object(builder, "radio_digital"));
radio_fans		= GTK_WIDGET(gtk_builder_get_object(builder, "radio_fans"));
web_entry		= GTK_WIDGET(gtk_builder_get_object(builder, "web_entry"));
mini_mode		= GTK_WIDGET(gtk_builder_get_object(builder, "mini_mode"));
web_button		= GTK_WIDGET(gtk_builder_get_object(builder, "web_button"));
camdraw			= GTK_WIDGET(gtk_builder_get_object(builder, "camdraw"));
antenna			= GTK_WIDGET(gtk_builder_get_object(builder, "antenna"));
switcher1		= GTK_WIDGET(gtk_builder_get_object(builder, "switcher1"));
pg			= GTK_WIDGET(gtk_builder_get_object(builder, "pg"));
stack1			= GTK_WIDGET(gtk_builder_get_object(builder, "stack1"));
zoom_level		= GTK_WIDGET(gtk_builder_get_object(builder, "zoom_level"));
bandstart		= GTK_WIDGET(gtk_builder_get_object(builder, "bandstart"));
bandwidth		= GTK_WIDGET(gtk_builder_get_object(builder, "bandwidth"));
show_video		= GTK_WIDGET(gtk_builder_get_object(builder, "show_video"));
recenter1      		= GTK_WIDGET(gtk_builder_get_object(builder, "recenter1"));
noMove1      		= GTK_WIDGET(gtk_builder_get_object(builder, "noMove1"));
micThreshold1		= GTK_WIDGET(gtk_builder_get_object(builder, "micThreshold1"));
about			= GTK_WIDGET(gtk_builder_get_object(builder, "about"));
Cam0			= GTK_WIDGET(gtk_builder_get_object(builder, "Cam0"));
cam0_image		= GTK_WIDGET(gtk_builder_get_object(builder, "cam0_image"));
time_of_day		= GTK_WIDGET(gtk_builder_get_object(builder, "time_of_day"));
above_bars		= GTK_WIDGET(gtk_builder_get_object(builder, "above_bars"));
addEntry1		= GTK_WIDGET(gtk_builder_get_object(builder, "addEntry1"));
adjustment10		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment10"));
adjustment11		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment11"));
adjustment12		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment12"));
adjustment13		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment13"));
adjustment14		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment14"));
adjustment15		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment15"));
adjustment16		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment16"));
adjustment17		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment17"));
adjustment18		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment18"));
adjustment19		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment19"));
adjustment20		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment20"));
adjustment32		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment32"));
adjustment49		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment49"));
adjustment45		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment45"));
agc			= GTK_WIDGET(gtk_builder_get_object(builder, "agc"));
ray_rotate		= GTK_WIDGET(gtk_builder_get_object(builder, "ray_rotate"));
sprinkle_count		= GTK_WIDGET(gtk_builder_get_object(builder, "sprinkle_count"));
agcLbl1			= GTK_WIDGET(gtk_builder_get_object(builder, "agcLbl1"));
agcLbl2			= GTK_WIDGET(gtk_builder_get_object(builder, "agcLbl2"));
agcMod			= GTK_WIDGET(gtk_builder_get_object(builder, "agcMod"));
albumBack		= GTK_WIDGET(gtk_builder_get_object(builder, "albumBack"));
albumForward		= GTK_WIDGET(gtk_builder_get_object(builder, "albumForward"));
albumScroll		= GTK_WIDGET(gtk_builder_get_object(builder, "albumScroll"));
alt_search1		= GTK_ENTRY(gtk_builder_get_object(builder, "alt_search1"));
alt_search		= GTK_ENTRY(gtk_builder_get_object(builder, "alt_search"));
audioCalibrate		= GTK_WIDGET(gtk_builder_get_object(builder, "audioCalibrate"));
audio			= GTK_WIDGET(gtk_builder_get_object(builder, "audio"));
background		= GTK_WIDGET(gtk_builder_get_object(builder, "background"));
barWidth		= GTK_WIDGET(gtk_builder_get_object(builder, "barWidth"));
bullseye		= GTK_WIDGET(gtk_builder_get_object(builder, "bullseye"));
button10		= GTK_WIDGET(gtk_builder_get_object(builder, "button10"));
button11		= GTK_WIDGET(gtk_builder_get_object(builder, "button11"));
button12		= GTK_WIDGET(gtk_builder_get_object(builder, "button12"));
button13		= GTK_WIDGET(gtk_builder_get_object(builder, "button13"));
button14		= GTK_WIDGET(gtk_builder_get_object(builder, "button14"));
button15		= GTK_WIDGET(gtk_builder_get_object(builder, "button15"));
button1			= GTK_WIDGET(gtk_builder_get_object(builder, "button1"));
button2			= GTK_WIDGET(gtk_builder_get_object(builder, "button2"));
button3			= GTK_WIDGET(gtk_builder_get_object(builder, "button3"));
button5			= GTK_WIDGET(gtk_builder_get_object(builder, "button5"));
button6			= GTK_WIDGET(gtk_builder_get_object(builder, "button6"));
button8			= GTK_WIDGET(gtk_builder_get_object(builder, "button8"));
button9			= GTK_WIDGET(gtk_builder_get_object(builder, "button9"));
calibrateLbl		= GTK_WIDGET(gtk_builder_get_object(builder, "calibrateLbl"));
cbox1			= GTK_WIDGET(gtk_builder_get_object(builder, "cbox1"));
check10			= GTK_WIDGET(gtk_builder_get_object(builder, "check10"));
check11			= GTK_WIDGET(gtk_builder_get_object(builder, "check11"));
check12			= GTK_WIDGET(gtk_builder_get_object(builder, "check12"));
check1			= GTK_WIDGET(gtk_builder_get_object(builder, "check1"));
check2			= GTK_WIDGET(gtk_builder_get_object(builder, "check2"));
check3			= GTK_WIDGET(gtk_builder_get_object(builder, "check3"));
check4			= GTK_WIDGET(gtk_builder_get_object(builder, "check4"));
check5			= GTK_WIDGET(gtk_builder_get_object(builder, "check5"));
check6			= GTK_WIDGET(gtk_builder_get_object(builder, "check6"));
check7			= GTK_WIDGET(gtk_builder_get_object(builder, "check7"));
check8          	= GTK_WIDGET(gtk_builder_get_object(builder, "check8"));
check9          	= GTK_WIDGET(gtk_builder_get_object(builder, "check9"));
choose1         	= GTK_WIDGET(gtk_builder_get_object(builder, "choose1"));
circular        	= GTK_WIDGET(gtk_builder_get_object(builder, "circular"));
classical       	= GTK_WIDGET(gtk_builder_get_object(builder, "classical"));
clevel          	= GTK_WIDGET(gtk_builder_get_object(builder, "clevel"));
clipThreshold   	= GTK_WIDGET(gtk_builder_get_object(builder, "clipThreshold"));
clrPgm          	= GTK_WIDGET(gtk_builder_get_object(builder, "clrPgm"));
clrPgm1          	= GTK_WIDGET(gtk_builder_get_object(builder, "clrPgm1"));
club            	= GTK_WIDGET(gtk_builder_get_object(builder, "club"));
connectGraph    	= GTK_WIDGET(gtk_builder_get_object(builder, "connectGraph"));
controls        	= GTK_WIDGET(gtk_builder_get_object(builder, "controls"));
movie        		= GTK_WIDGET(gtk_builder_get_object(builder, "movie"));
covers          	= GTK_WIDGET(gtk_builder_get_object(builder, "covers"));
currentFile     	= GTK_WIDGET(gtk_builder_get_object(builder, "currentFile"));
dance           	= GTK_WIDGET(gtk_builder_get_object(builder, "dance"));
decorations     	= GTK_WIDGET(gtk_builder_get_object(builder, "decorations"));
del10           	= GTK_WIDGET(gtk_builder_get_object(builder, "del10"));
del11           	= GTK_WIDGET(gtk_builder_get_object(builder, "del11"));
del12           	= GTK_WIDGET(gtk_builder_get_object(builder, "del12"));
del13           	= GTK_WIDGET(gtk_builder_get_object(builder, "del13"));
del14           	= GTK_WIDGET(gtk_builder_get_object(builder, "del14"));
del15           	= GTK_WIDGET(gtk_builder_get_object(builder, "del15"));
del2            	= GTK_WIDGET(gtk_builder_get_object(builder, "del2"));
del3            	= GTK_WIDGET(gtk_builder_get_object(builder, "del3"));
del4            	= GTK_WIDGET(gtk_builder_get_object(builder, "del4"));
del7            	= GTK_WIDGET(gtk_builder_get_object(builder, "del7"));
del8            	= GTK_WIDGET(gtk_builder_get_object(builder, "del8"));
del9            	= GTK_WIDGET(gtk_builder_get_object(builder, "del9"));
displayBars     	= GTK_WIDGET(gtk_builder_get_object(builder, "displayBars"));
draw1           	= GTK_WIDGET(gtk_builder_get_object(builder, "draw1"));
drawV           	= GTK_WIDGET(gtk_builder_get_object(builder, "drawV"));
draw2           	= GTK_WIDGET(gtk_builder_get_object(builder, "draw2"));
draw3           	= GTK_WIDGET(gtk_builder_get_object(builder, "draw3"));
draw4           	= GTK_WIDGET(gtk_builder_get_object(builder, "draw4"));
video_draw           	= GTK_WIDGET(gtk_builder_get_object(builder, "video_draw"));
dxb1            	= GTK_WIDGET(gtk_builder_get_object(builder, "dxb1"));
dxb2            	= GTK_WIDGET(gtk_builder_get_object(builder, "dxb2"));
egg_image       	= GTK_WIDGET(gtk_builder_get_object(builder, "egg_image"));
empty           	= GTK_WIDGET(gtk_builder_get_object(builder, "empty"));
entry10         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry10"));
entry11         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry11"));
entry12         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry12"));
entry13         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry13"));
entry14         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry14"));
entry15         	= GTK_ENTRY(gtk_builder_get_object(builder, "entry15"));
entry1          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry1"));
entry2          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry2"));
entry3          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry3"));
entry4          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry4"));
entry7          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry7"));
entry8          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry8"));
entry9          	= GTK_ENTRY(gtk_builder_get_object(builder, "entry9"));
eqReset         	= GTK_WIDGET(gtk_builder_get_object(builder, "eqReset"));
finish_pgm      	= GTK_WIDGET(gtk_builder_get_object(builder, "finish_pgm"));
finish_pgm1      	= GTK_WIDGET(gtk_builder_get_object(builder, "finish_pgm1"));
first           	= GTK_WIDGET(gtk_builder_get_object(builder, "first"));
fixed1          	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed1"));
fixed2          	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed2"));
fixed_slides    	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed_slides"));
flat            	= GTK_WIDGET(gtk_builder_get_object(builder, "flat"));
fullBass        	= GTK_WIDGET(gtk_builder_get_object(builder, "fullBass"));
fullBassTreble  	= GTK_WIDGET(gtk_builder_get_object(builder, "fullBassTreble"));
fullTreble      	= GTK_WIDGET(gtk_builder_get_object(builder, "fullTreble"));
g_btn_play      	= GTK_WIDGET(gtk_builder_get_object(builder, "button1"));
g_dbox1Entry    	= GTK_ENTRY(gtk_builder_get_object(builder,  "dbox1Entry"));
g_dbox1         	= GTK_WIDGET(gtk_builder_get_object(builder, "dbox1"));
h1000           	= GTK_WIDGET(gtk_builder_get_object(builder, "h1000"));
h12000          	= GTK_WIDGET(gtk_builder_get_object(builder, "h12000"));
h14000          	= GTK_WIDGET(gtk_builder_get_object(builder, "h14000"));
h16000          	= GTK_WIDGET(gtk_builder_get_object(builder, "h16000"));
h170            	= GTK_WIDGET(gtk_builder_get_object(builder, "h170"));
h3000           	= GTK_WIDGET(gtk_builder_get_object(builder, "h3000"));
h310            	= GTK_WIDGET(gtk_builder_get_object(builder, "h310"));
h6000           	= GTK_WIDGET(gtk_builder_get_object(builder, "h6000"));
h600            	= GTK_WIDGET(gtk_builder_get_object(builder, "h600"));
h60             	= GTK_WIDGET(gtk_builder_get_object(builder, "h60"));
haltProgram     	= GTK_WIDGET(gtk_builder_get_object(builder, "haltProgram"));
//haltProgram1     	= GTK_WIDGET(gtk_builder_get_object(builder, "haltProgram1"));
headphones      	= GTK_WIDGET(gtk_builder_get_object(builder, "headphones"));
highLabel       	= GTK_WIDGET(gtk_builder_get_object(builder, "highLabel"));
horLabel        	= GTK_WIDGET(gtk_builder_get_object(builder, "horLabel"));
image13         	= GTK_WIDGET(gtk_builder_get_object(builder, "image13"));
image14         	= GTK_WIDGET(gtk_builder_get_object(builder, "image14"));
image15         	= GTK_WIDGET(gtk_builder_get_object(builder, "image15"));
image16         	= GTK_WIDGET(gtk_builder_get_object(builder, "image16"));
image17         	= GTK_WIDGET(gtk_builder_get_object(builder, "image17"));
image18         	= GTK_WIDGET(gtk_builder_get_object(builder, "image18"));
image19         	= GTK_WIDGET(gtk_builder_get_object(builder, "image19"));
image20         	= GTK_WIDGET(gtk_builder_get_object(builder, "image20"));
image21         	= GTK_WIDGET(gtk_builder_get_object(builder, "image21"));
L1000           	= GTK_WIDGET(gtk_builder_get_object(builder, "L1000"));
L10             	= GTK_WIDGET(gtk_builder_get_object(builder, "L10"));
L12000          	= GTK_WIDGET(gtk_builder_get_object(builder, "L12000"));
L14000          	= GTK_WIDGET(gtk_builder_get_object(builder, "L14000"));
L16000          	= GTK_WIDGET(gtk_builder_get_object(builder, "L16000"));
L170            	= GTK_WIDGET(gtk_builder_get_object(builder, "L170"));
L1              	= GTK_WIDGET(gtk_builder_get_object(builder, "L1"));
L2              	= GTK_WIDGET(gtk_builder_get_object(builder, "L2"));
L3000           	= GTK_WIDGET(gtk_builder_get_object(builder, "L3000"));
L310            	= GTK_WIDGET(gtk_builder_get_object(builder, "L310"));
L3              	= GTK_WIDGET(gtk_builder_get_object(builder, "L3"));
L4              	= GTK_WIDGET(gtk_builder_get_object(builder, "L4"));
L5              	= GTK_WIDGET(gtk_builder_get_object(builder, "L5"));
L6000           	= GTK_WIDGET(gtk_builder_get_object(builder, "L6000"));
L600            	= GTK_WIDGET(gtk_builder_get_object(builder, "L600"));
L60             	= GTK_WIDGET(gtk_builder_get_object(builder, "L60"));
L6              	= GTK_WIDGET(gtk_builder_get_object(builder, "L6"));
L7              	= GTK_WIDGET(gtk_builder_get_object(builder, "L7"));
L8              	= GTK_WIDGET(gtk_builder_get_object(builder, "L8"));
L9              	= GTK_WIDGET(gtk_builder_get_object(builder, "L9"));
largeHall       	= GTK_WIDGET(gtk_builder_get_object(builder, "largeHall"));
Lattack         	= GTK_WIDGET(gtk_builder_get_object(builder, "Lattack"));
lbl10           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl10"));
lbl11           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl11"));
lbl12           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl12"));
lbl13           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl13"));
lbl14           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl14"));
lbl15           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl15"));
lbl16           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl16"));
lbl17           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl17"));
lbl18           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl18"));
lbl19           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl19"));
lbl1            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl1"));
lbl20           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl20"));
lbl21           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl21"));
lbl22           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl22"));
lbl23           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl23"));
lbl24           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl24"));
lbl25           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl25"));
lbl2            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl2"));
lbl3            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl3"));
lbl4            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl4"));
lbl5            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl5"));
lbl6            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl6"));
lbl7            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl7"));
lbl8            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl8"));
lbl9            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl9"));
live            	= GTK_WIDGET(gtk_builder_get_object(builder, "live"));
Lknee           	= GTK_WIDGET(gtk_builder_get_object(builder, "Lknee"));
Lmakeup         	= GTK_WIDGET(gtk_builder_get_object(builder, "Lmakeup"));
Lratio          	= GTK_WIDGET(gtk_builder_get_object(builder, "Lratio"));
Lrelease        	= GTK_WIDGET(gtk_builder_get_object(builder, "Lrelease"));
Lrmspeak        	= GTK_WIDGET(gtk_builder_get_object(builder, "Lrmspeak"));
Lthreshold      	= GTK_WIDGET(gtk_builder_get_object(builder, "Lthreshold"));
masterVolLevel  	= GTK_WIDGET(gtk_builder_get_object(builder, "masterVolLevel"));
masterVolume    	= GTK_WIDGET(gtk_builder_get_object(builder, "masterVolume"));
maxGain         	= GTK_WIDGET(gtk_builder_get_object(builder, "maxGain"));
mediaGain       	= GTK_WIDGET(gtk_builder_get_object(builder, "mediaGain"));
meters          	= GTK_WIDGET(gtk_builder_get_object(builder, "meters"));
micMute         	= GTK_WIDGET(gtk_builder_get_object(builder, "micMute"));
more            	= GTK_WIDGET(gtk_builder_get_object(builder, "more"));
nextPlay        	= GTK_WIDGET(gtk_builder_get_object(builder, "nextPlay"));
openMedia       	= GTK_WIDGET(gtk_builder_get_object(builder, "openMedia"));
openMedia       	= GTK_WIDGET(gtk_builder_get_object(builder, "openMedia"));
p10             	= GTK_WIDGET(gtk_builder_get_object(builder, "p10"));
p10TimeEnd      	= GTK_WIDGET(gtk_builder_get_object(builder, "p10TimeEnd"));
p10Time         	= GTK_WIDGET(gtk_builder_get_object(builder, "p10Time"));
p10TimeLength   	= GTK_WIDGET(gtk_builder_get_object(builder, "p10TimeLength"));
p11             	= GTK_WIDGET(gtk_builder_get_object(builder, "p11"));
p11TimeEnd      	= GTK_WIDGET(gtk_builder_get_object(builder, "p11TimeEnd"));
p11Time         	= GTK_WIDGET(gtk_builder_get_object(builder, "p11Time"));
p11TimeLength   	= GTK_WIDGET(gtk_builder_get_object(builder, "p11TimeLength"));
p12             	= GTK_WIDGET(gtk_builder_get_object(builder, "p12"));
p12TimeEnd      	= GTK_WIDGET(gtk_builder_get_object(builder, "p12TimeEnd"));
p12Time         	= GTK_WIDGET(gtk_builder_get_object(builder, "p12Time"));
p12TimeLength   	= GTK_WIDGET(gtk_builder_get_object(builder, "p12TimeLength"));
p13             	= GTK_WIDGET(gtk_builder_get_object(builder, "p13"));
p14             	= GTK_WIDGET(gtk_builder_get_object(builder, "p14"));
p15             	= GTK_WIDGET(gtk_builder_get_object(builder, "p15"));
p16             	= GTK_WIDGET(gtk_builder_get_object(builder, "p16"));
p17             	= GTK_WIDGET(gtk_builder_get_object(builder, "p17"));
p18             	= GTK_WIDGET(gtk_builder_get_object(builder, "p18"));
p19             	= GTK_WIDGET(gtk_builder_get_object(builder, "p19"));
p1              	= GTK_WIDGET(gtk_builder_get_object(builder, "p1"));
p1TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p1TimeEnd"));
p1Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p1Time"));
p1TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p1TimeLength"));
p20             	= GTK_WIDGET(gtk_builder_get_object(builder, "p20"));
p21             	= GTK_WIDGET(gtk_builder_get_object(builder, "p21"));
p22             	= GTK_WIDGET(gtk_builder_get_object(builder, "p22"));
p23             	= GTK_WIDGET(gtk_builder_get_object(builder, "p23"));
p24             	= GTK_WIDGET(gtk_builder_get_object(builder, "p24"));
p25             	= GTK_WIDGET(gtk_builder_get_object(builder, "p25"));
p2              	= GTK_WIDGET(gtk_builder_get_object(builder, "p2"));
p2TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p2TimeEnd"));
p2Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p2Time"));
p2TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p2TimeLength"));
p3              	= GTK_WIDGET(gtk_builder_get_object(builder, "p3"));
p3TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p3TimeEnd"));
p3Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p3Time"));
p3TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p3TimeLength"));
p4              	= GTK_WIDGET(gtk_builder_get_object(builder, "p4"));
p4TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p4TimeEnd"));
p4Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p4Time"));
p4TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p4TimeLength"));
p5              	= GTK_WIDGET(gtk_builder_get_object(builder, "p5"));
p5TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p5TimeEnd"));
p5Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p5Time"));
p5TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p5TimeLength"));
p6              	= GTK_WIDGET(gtk_builder_get_object(builder, "p6"));
p6TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p6TimeEnd"));
p6Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p6Time"));
p6TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p6TimeLength"));
p7              	= GTK_WIDGET(gtk_builder_get_object(builder, "p7"));
p7TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p7TimeEnd"));
p7Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p7Time"));
p7TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p7TimeLength"));
p8              	= GTK_WIDGET(gtk_builder_get_object(builder, "p8"));
p8TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p8TimeEnd"));
p8Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p8Time"));
p8TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p8TimeLength"));
p9              	= GTK_WIDGET(gtk_builder_get_object(builder, "p9"));
p9TimeEnd       	= GTK_WIDGET(gtk_builder_get_object(builder, "p9TimeEnd"));
p9Time          	= GTK_WIDGET(gtk_builder_get_object(builder, "p9Time"));
p9TimeLength    	= GTK_WIDGET(gtk_builder_get_object(builder, "p9TimeLength"));
party           	= GTK_WIDGET(gtk_builder_get_object(builder, "party"));
pauseAtEnd      	= GTK_WIDGET(gtk_builder_get_object(builder, "pauseAtEnd"));
pauseVideo      	= GTK_WIDGET(gtk_builder_get_object(builder, "pauseVideo"));
pg0             	= GTK_WIDGET(gtk_builder_get_object(builder, "pg0"));
pg1             	= GTK_WIDGET(gtk_builder_get_object(builder, "pg1"));
pg2             	= GTK_WIDGET(gtk_builder_get_object(builder, "pg2"));
pg8             	= GTK_WIDGET(gtk_builder_get_object(builder, "pg8"));
Playerx         	= GTK_WIDGET(gtk_builder_get_object(builder, "Playerx"));
Playerx1         	= GTK_WIDGET(gtk_builder_get_object(builder, "Playerx1"));
PlayPgm         	= GTK_WIDGET(gtk_builder_get_object(builder, "PlayPgm"));
PlayPgm1         	= GTK_WIDGET(gtk_builder_get_object(builder, "PlayPgm1"));
pop             	= GTK_WIDGET(gtk_builder_get_object(builder, "pop"));
posLbl          	= GTK_WIDGET(gtk_builder_get_object(builder, "posLbl"));
preAmp1Label            = GTK_WIDGET(gtk_builder_get_object(builder, "preAmp1Label"));
preAmp          	= GTK_WIDGET(gtk_builder_get_object(builder, "preAmp"));
preAmpLbl1      	= GTK_WIDGET(gtk_builder_get_object(builder, "preAmpLbl1"));
preampLbl       	= GTK_WIDGET(gtk_builder_get_object(builder, "preampLbl"));
presetBack      	= GTK_WIDGET(gtk_builder_get_object(builder, "presetBack"));
programMode     	= GTK_WIDGET(gtk_builder_get_object(builder, "programMode"));
programMode1     	= GTK_WIDGET(gtk_builder_get_object(builder, "programMode1"));
radial_decay    	= GTK_WIDGET(gtk_builder_get_object(builder, "radial_decay"));
radial_start    	= GTK_WIDGET(gtk_builder_get_object(builder, "radial_start"));
rampDown        	= GTK_WIDGET(gtk_builder_get_object(builder, "rampDown"));
rampUp          	= GTK_WIDGET(gtk_builder_get_object(builder, "rampUp"));
randColors      	= GTK_WIDGET(gtk_builder_get_object(builder, "randColors"));
randomize       	= GTK_WIDGET(gtk_builder_get_object(builder, "randomize"));
randomize1       	= GTK_WIDGET(gtk_builder_get_object(builder, "randomize1"));
rayCount        	= GTK_WIDGET(gtk_builder_get_object(builder, "rayCount"));
rayLbl          	= GTK_WIDGET(gtk_builder_get_object(builder, "rayLbl"));
recenter        	= GTK_WIDGET(gtk_builder_get_object(builder, "recenter"));
reggae          	= GTK_WIDGET(gtk_builder_get_object(builder, "reggae"));
rock            	= GTK_WIDGET(gtk_builder_get_object(builder, "rock"));
save1           	= GTK_WIDGET(gtk_builder_get_object(builder, "save1"));
save2           	= GTK_WIDGET(gtk_builder_get_object(builder, "save2"));
save3           	= GTK_WIDGET(gtk_builder_get_object(builder, "save3"));
save4           	= GTK_WIDGET(gtk_builder_get_object(builder, "save4"));
scan_times      	= GTK_WIDGET(gtk_builder_get_object(builder, "scan_times"));
scan_times1      	= GTK_WIDGET(gtk_builder_get_object(builder, "scan_times1"));
scroll2         	= GTK_WIDGET(gtk_builder_get_object(builder, "scroll2"));
scroll          	= GTK_WIDGET(gtk_builder_get_object(builder, "scroll"));
search_again1   	= GTK_WIDGET(gtk_builder_get_object(builder, "search_again1"));
search_again    	= GTK_WIDGET(gtk_builder_get_object(builder, "search_again"));
search_scroll   	= GTK_WIDGET(gtk_builder_get_object(builder, "search_scroll"));
sgrStudio       	= GTK_WIDGET(gtk_builder_get_object(builder, "sgrStudio"));
shadow_offset   	= GTK_WIDGET(gtk_builder_get_object(builder, "shadow_offset"));
shadowWidthLbl  	= GTK_WIDGET(gtk_builder_get_object(builder, "shadowWidthLbl"));
showCovers      	= GTK_WIDGET(gtk_builder_get_object(builder, "showCovers"));
showCurrent     	= GTK_WIDGET(gtk_builder_get_object(builder, "showCurrent"));
showCurrent1     	= GTK_WIDGET(gtk_builder_get_object(builder, "showCurrent1"));
SideSlidePanel  	= GTK_WIDGET(gtk_builder_get_object(builder, "SideSlidePanel"));
sink            	= GTK_WIDGET(gtk_builder_get_object(builder, "sink"));
ska             	= GTK_WIDGET(gtk_builder_get_object(builder, "ska"));
skipNext        	= GTK_WIDGET(gtk_builder_get_object(builder, "skipNext"));
skipThis        	= GTK_WIDGET(gtk_builder_get_object(builder, "skipThis"));
SlidesImage     	= GTK_WIDGET(gtk_builder_get_object(builder, "SlidesImage"));
slideTime       	= GTK_WIDGET(gtk_builder_get_object(builder, "slideTime"));
soft            	= GTK_WIDGET(gtk_builder_get_object(builder, "soft"));
softRock        	= GTK_WIDGET(gtk_builder_get_object(builder, "softRock"));
sort            	= GTK_WIDGET(gtk_builder_get_object(builder, "sort"));
sort1            	= GTK_WIDGET(gtk_builder_get_object(builder, "sort1"));
source          	= GTK_WIDGET(gtk_builder_get_object(builder, "source"));
spec12          	= GTK_WIDGET(gtk_builder_get_object(builder, "spec12"));
spec20          	= GTK_WIDGET(gtk_builder_get_object(builder, "spec20"));
spec7           	= GTK_WIDGET(gtk_builder_get_object(builder, "spec7"));
spikes1         	= GTK_WIDGET(gtk_builder_get_object(builder, "spikes1"));
spikes          	= GTK_WIDGET(gtk_builder_get_object(builder, "spikes"));
sprinkle_acc    	= GTK_WIDGET(gtk_builder_get_object(builder, "sprinkle_acc"));
sprinkle_gravity    	= GTK_WIDGET(gtk_builder_get_object(builder, "sprinkle_gravity"));
stk1            	= GTK_WIDGET(gtk_builder_get_object(builder, "stk1"));
sw1             	= GTK_WIDGET(gtk_builder_get_object(builder, "sw1"));
techno          	= GTK_WIDGET(gtk_builder_get_object(builder, "techno"));
timeNext        	= GTK_WIDGET(gtk_builder_get_object(builder, "timeNext"));
timer           	= GTK_WIDGET(gtk_builder_get_object(builder, "timer"));
TimeToHour      	= GTK_WIDGET(gtk_builder_get_object(builder, "TimeToHour"));
tooltips        	= GTK_WIDGET(gtk_builder_get_object(builder, "tooltips"));
Top1            	= GTK_WIDGET(gtk_builder_get_object(builder, "Top1"));
TopTop            	= GTK_WIDGET(gtk_builder_get_object(builder, "TopTop"));
tower_circles    	= GTK_WIDGET(gtk_builder_get_object(builder, "tower_circles"));
tower    		= GTK_WIDGET(gtk_builder_get_object(builder, "tower"));
tower_rays    		= GTK_WIDGET(gtk_builder_get_object(builder, "tower_rays"));
traces          	= GTK_WIDGET(gtk_builder_get_object(builder, "traces"));
up10            	= GTK_WIDGET(gtk_builder_get_object(builder, "up10"));
up11            	= GTK_WIDGET(gtk_builder_get_object(builder, "up11"));
up12            	= GTK_WIDGET(gtk_builder_get_object(builder, "up12"));
up1             	= GTK_WIDGET(gtk_builder_get_object(builder, "up1"));
up2             	= GTK_WIDGET(gtk_builder_get_object(builder, "up2"));
up3             	= GTK_WIDGET(gtk_builder_get_object(builder, "up3"));
up4             	= GTK_WIDGET(gtk_builder_get_object(builder, "up4"));
up5             	= GTK_WIDGET(gtk_builder_get_object(builder, "up5"));
up6             	= GTK_WIDGET(gtk_builder_get_object(builder, "up6"));
up7             	= GTK_WIDGET(gtk_builder_get_object(builder, "up7"));
up8             	= GTK_WIDGET(gtk_builder_get_object(builder, "up8"));
up9             	= GTK_WIDGET(gtk_builder_get_object(builder, "up9"));
verLabel        	= GTK_WIDGET(gtk_builder_get_object(builder, "verLabel"));
visual          	= GTK_WIDGET(gtk_builder_get_object(builder, "visual"));
vlcPosition     	= GTK_WIDGET(gtk_builder_get_object(builder, "vlcPosition"));
vlcSpinRate     	= GTK_WIDGET(gtk_builder_get_object(builder, "vlcSpinRate"));
vumeter1        	= GTK_WIDGET(gtk_builder_get_object(builder, "vumeter1"));
vumeter         	= GTK_WIDGET(gtk_builder_get_object(builder, "vumeter"));
wideLabel       	= GTK_WIDGET(gtk_builder_get_object(builder, "wideLabel"));




//---------------------------------------------------------------------
// get the definitions of the major components / widgets
//---------------------------------------------------------------------

adjustment34	= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment34"));
adjustment35	= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment35"));
adjustment8	= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment8"));
adjustment9	= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment9"));

cam0_active	= GTK_WIDGET(gtk_builder_get_object(builder, "cam0_active"));

micThreshold1	= GTK_WIDGET(gtk_builder_get_object(builder, "micThreshold1"));

//	randomize2	= GTK_WIDGET(gtk_builder_get_object(builder, "randomize2"));
//	search_again2	= GTK_WIDGET(gtk_builder_get_object(builder, "search_again2"));

showCurrent2	= GTK_WIDGET(gtk_builder_get_object(builder, "showCurrent2"));
//	sort1		= GTK_WIDGET(gtk_builder_get_object(builder, "sort1"));

//	xbox2		= GTK_WIDGET(gtk_builder_get_object(builder, "xbox2"));


#endif
