button {
  min-height: 22px;
  min-width: 00px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border: 1px solid;
  border-radius: 3px;
  padding: 0px 0px;
  color: #101010;
  outline-color: rgba(48, 48, 48, 0.3);
  border-color: #BDBDBD;
  background-color: #555577; }
