/* default coloring of widgets */
* {
    background-color: #bbbbdd;    
}

button {
    color: #000000;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    border-radius: 6px;
    padding-right: 2px;
    padding-left: 2px;
    padding-top: 2px;
    padding-bottom: 2px;
    background-image: radial-gradient(ellipse at center, lightblue 20%, slategray 80%);
}


button:active, button.toggle-button.selected, button.toggle-button:active, button.toggle:checked 
{ background-image: radial-gradient(ellipse at center, slategray 20%, lightblue 80%); }
